DROP TABLE BudgetItem;
DROP TABLE ExpenseItem;
DROP TABLE ExpenseReport;
DROP TABLE Users;
DROP TABLE Asset;
DROP TABLE OrgUnit;
DROP TABLE expcat;

DROP SEQUENCE expenseitem_seq;
DROP SEQUENCE expensereport_seq;
DROP SEQUENCE users_seq;
DROP SEQUENCE asset_seq; 
DROP SEQUENCE orgunit_seq;
DROP SEQUENCE expcat_seq;
DROP SEQUENCE budgetitem_seq;

ALTER SESSION SET NLS_DATE_FORMAT = 'MM/DD/YYYY HH:MI:SS';

CREATE TABLE Asset (
AssetNo		INT				NOT NULL	PRIMARY KEY,
AssetDesc   VARCHAR2(255)	NOT NULL);
	
CREATE SEQUENCE asset_seq INCREMENT BY  1;

INSERT INTO Asset
	(AssetNo, AssetDesc)
	VALUES (1,'Company Car');


INSERT INTO Asset
	(AssetNo, AssetDesc)
	VALUES (2,'Company Jet');


INSERT INTO Asset
	(AssetNo, AssetDesc)
	VALUES (3,'Company Van');


INSERT INTO Asset
	(AssetNo, AssetDesc)
	VALUES (4,'Company Truck');
			
/****************************************************************************************/

CREATE TABLE OrgUnit (
OrgNo		INT				NOT NULL	PRIMARY KEY,
OrgName		VARCHAR2(50)	NOT NULL,
OrgParentNo	INT,
CONSTRAINT ParentOrgUnit_FK
	FOREIGN KEY (OrgParentNo) REFERENCES OrgUnit (OrgNo) );

CREATE SEQUENCE orgunit_seq INCREMENT BY  1;

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (1,'Accounting', NULL );

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (2,'Sales', NULL);

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (3,'IT', NULL);

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (4,'IT Development',3);

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (5,'Accounts Receivable',1);

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (6,'IT Support',3);

INSERT INTO OrgUnit 
	(OrgNo, OrgName, OrgParentNo)
	VALUES (7,'Accounts Payable',1);


/**********************************************************************************/

CREATE TABLE ExpCat (
ECNo		INT				NOT NULL	PRIMARY KEY,
ECName		VARCHAR2(25)	NOT NULL,
ECLimit		NUMBER(8,2)		DEFAULT 0	NOT NULL);

CREATE SEQUENCE expcat_seq INCREMENT BY  1;

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (1,'Dinner',50.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (2,'Car Rental',100.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (3,'Breakfast',25.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (4,'Local Transportation',100.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (5,'Airfare',5000.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (6,'Lunch',25.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (7,'Lodging',300.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (8,'Admission Fee',2000.00);

INSERT INTO ExpCat
	(ECNo, ECName, ECLimit)
	VALUES (9,'Gas',35.00);


/****************************************************************************/

CREATE TABLE Users (
UserNo			INT				NOT NULL	PRIMARY KEY,
UserFirstName	VARCHAR2(50)	NOT NULL,
UserLastName	VARCHAR2(50)	NOT NULL,
UserPhone		VARCHAR2(20),
UserEmail		VARCHAR2(50)	NOT NULL,
UserOrgNo		INT				NOT NULL,
CONSTRAINT UserOrg_FK
	FOREIGN KEY (UserOrgNo) REFERENCES OrgUnit (OrgNo),
CONSTRAINT CK_EMAIL CHECK (Useremail LIKE '%@%') );

CREATE SEQUENCE users_seq INCREMENT BY  1;

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (1,'Sue','Herdon','(206) 339-3312','sherdon@org.com',3);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (2,'Bill','Jones','(303) 205-8833','bjones@org.com',6);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (3,'Joe','Smith','(303) 443-9943','jsmith@org.com',4);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (4,'William','Freed','(303) 445-3355','wfreed@org.com',1);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (5,'Sara','Jonson','(303) 445-3321','sjonson@org.com',7);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (6,'Tom','Sanchez','(303) 445-3322','tsanchez@org.com',5);

INSERT INTO Users
	(UserNo, UserFirstName, UserLastName, UserPhone, UserEmail, UserOrgNo)
	VALUES (7,'Marry','Blake','(303) 445-3333','mblake@org.com',2);

/*******************************************************************************/

CREATE TABLE ExpenseReport (
ERNo			INT				NOT NULL 	PRIMARY KEY,
ERDesc			VARCHAR2(255)	NOT NULL,
ERSubmitDate	Date			DEFAULT SYSDATE		NOT NULL,
ERStatusDate	Date			DEFAULT SYSDATE		NOT NULL,
ERStatus		VARCHAR2(10)	DEFAULT 'PENDING'	NOT NULL,
SubmitUserNo	INT				NOT NULL,
ApprUserNo		INT,
CONSTRAINT	ExpenseReportUser_FK
	FOREIGN KEY (SubmitUserNo)	REFERENCES Users (UserNo),
CONSTRAINT	ExpenseReportApprUser_FK
	FOREIGN KEY (ApprUserNo) REFERENCES	Users (UserNo),
CONSTRAINT check_Status
	CHECK (ERStatus IN ('PENDING','APPROVED','DENIED')),
CONSTRAINT CheckDates
	CHECK (ERStatusDate >= ERSubmitDate) );
	
CREATE SEQUENCE expensereport_seq INCREMENT BY  1;


INSERT INTO ExpenseReport 
	(ERNo, ERDesc, ERSubmitDate, ERStatusDate, ERStatus, SubmitUserNo, ApprUSerNo)
	VALUES (1,'Sales Presentation','8/10/2002','8/26/2002','APPROVED',3,4);

INSERT INTO ExpenseReport 
	(ERNo, ERDesc, ERSubmitDate, ERStatusDate, ERStatus, SubmitUserNo, ApprUSerNo)
	VALUES (2,'Conference','8/16/2002','8/17/2002','APPROVED',4,4);

INSERT INTO ExpenseReport 
	(ERNo, ERDesc, ERSubmitDate, ERStatusDate, ERStatus, SubmitUserNo, ApprUSerNo)
	VALUES (3,'Training Course','9/23/2002','9/25/2002','APPROVED',2,1);

INSERT INTO ExpenseReport 
	(ERNo, ERDesc, ERSubmitDate, ERStatusDate, ERStatus, SubmitUserNo, ApprUSerNo)
	VALUES (4,'IT Group Lunch','9/29/2002','9/29/2002' ,'APPROVED',1,4);

INSERT INTO ExpenseReport 
	(ERNo, ERDesc, ERSubmitDate, ERStatusDate, ERStatus, SubmitUserNo, ApprUSerNo)
	VALUES (5,'Sales Presentation','9/30/2002','10/1/2002','APPROVED',7,4);


/*************************************************************************************/

CREATE TABLE ExpenseItem (
EINo		INT				NOT NULL		PRIMARY KEY, 
ExpDesc		VARCHAR2(255)	NOT NULL,
ExpenseDate	DATE			DEFAULT SYSDATE	NOT NULL,
ExpAmt		NUMBER(8,2)		DEFAULT 0		NOT NULL,
ExpApprAmt	NUMBER(8,2)		DEFAULT 0,
ERNo		INT				NOT NULL,
ECNo		INT				NOT NULL,	
AssetNo		INT,
CONSTRAINT ExpenseItem_ER
	FOREIGN KEY (ERNo) REFERENCES ExpenseReport (ERno) ON DELETE CASCADE,
CONSTRAINT ExpenseItem_Cat
	Foreign KEY (ECNo) REFERENCES ExpCat (ECNo),
CONSTRAINT ExpenseItem_Asset
	FOREIGN KEY	(AssetNo) REFERENCES Asset (AssetNo) ON DELETE SET NULL, 
CONSTRAINT  ApprAmt
	CHECK (ExpApprAmt <= ExpAmt) );

CREATE SEQUENCE expenseitem_seq INCREMENT BY  1;

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES (2,'Hilton','8/9/2002',99.00,99.00,1,7,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(3,'Gas','8/9/2002',35.00,20.00,1,9,1);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(4,'Breakfast','8/10/2002',10.00,10.00,1,3,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(5,'Comfort Inn','8/16/2002',225.00,225.00,2,7,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(6,'Airfare','8/13/2002',325.00,325.00,2,5,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(7,'Dinner','8/15/2002',23.94,23.94,2,1,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(8,'Dinner','8/14/2002',32.50,32.50,2,1,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(9,'Dinner','8/13/2002',19.64,19.64,2,1,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(10,'Lunch','8/15/2002',25.00,25.00,2,6,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(11,'Breakfast','8/15/2002',10.32,10.32,2,3,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(12,'Motel 6','9/23/2002',57.95,57.95,3,7,NULL);

INSERT INTO ExpenseItem
	(EINo, ExpDesc, ExpenseDate,ExpAmt, ExpApprAmt, ERNo, ECNo, AssetNo)
	VALUES(13,'Gas','9/23/2002',15.94,15.94,3,9,3);

/***********************************************************************************/


CREATE TABLE BudgetItem (
BINo		INT			NOT NULL		PRIMARY KEY, 
BIYear		INTEGER		DEFAULT 2002	NOT NULL,
OrgNo		INT			NOT NULL,
ECNo		INT			NOT NULL,
BIAmt		NUMBER(10,2)		DEFAULT 0		NOT NULL,
BIActual	NUMBER(10,2)		DEFAULT 0		NOT NULL,
CONSTRAINT UNIQUE_BI
	UNIQUE (BIYEAR, OrgNo, ECNo),
CONSTRAINT BIOrg_FK
	FOREIGN KEY (OrgNo) REFERENCES OrgUnit (OrgNo),
CONSTRAINT BI_CatBI
	Foreign KEY (ECNo) REFERENCES ExpCat (ECNo),
CONSTRAINT check_year
	CHECK (BIYear > 1900) );

CREATE SEQUENCE budgetitem_seq INCREMENT BY  1;

INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (1,2002,1,1,4000.00,76.08);

INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (2,2002,1,2,3000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (3,2002,1,3,2000.00,10.32);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (4,2002,1,4,500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (5,2002,1,5,10000.00,325.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (6,2002,1,6,2000.00,25.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (7,2002,1,7,10000.00,225.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (8,2002,1,8,6000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (9,2002,1,9,5000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (10,2002,2,1,10000.00,167.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (11,2002,2,2,7500.00,98.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (12,2002,2,3,4000.00,10.75);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (13,2002,2,4,1500.00,5.50);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (14,2002,2,5,15000.00,650.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (15,2002,2,6,5000.00,6.79);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (16,2002,2,7,12000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (17,2002,2,8,7500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (18,2002,2,9,7500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (19,2002,3,1,4000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (20,2002,3,2,3000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (21,2002,3,3,2000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (22,2002,3,4,500.00,24.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (23,2002,3,5,10000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (24,2002,3,6,2000.00,75.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (25,2002,3,7,10000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (26,2002,3,8,10000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (27,2002,3,9,5000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (28,2002,4,1,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (29,2002,4,2,1200.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (30,2002,4,3,1000.00,10.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (31,2002,4,4,250.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (32,2002,4,5,4000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (33,2002,4,6,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (34,2002,4,7,2000.00,99.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (35,2002,4,8,8000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (36,2002,4,9,650.00,35.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (37,2002,5,1,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (38,2002,5,2,1200.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (39,2002,5,3,1000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (40,2002,5,4,250.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (41,2002,5,5,4000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (42,2002,5,6,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (43,2002,5,7,2000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (44,2002,5,8,5500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (45,2002,5,9,350.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (46,2002,6,1,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (47,2002,6,2,1200.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (48,2002,6,3,1000.00,2.99);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (49,2002,6,4,250.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (50,2002,6,5,4000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (51,2002,6,6,1500.00,5.95);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (52,2002,6,7,2000.00,57.95);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (53,2002,6,8,5500.00,1000.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (54,2002,6,9,350.00,15.94);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (55,2002,7,1,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (56,2002,7,2,1200.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (57,2002,7,3,1000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (58,2002,7,4,250.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (59,2002,7,5,4000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (60,2002,7,6,1500.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (61,2002,7,7,2000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (62,2002,7,8,8000.00,0.00);
INSERT INTO BudgetItem
	(BINo, BIYear, OrgNo, ECNo, BIAmt, BIActual)
	VALUES (63,2002,7,9,650.00,0.00);